'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _ansiEscapes = require('ansi-escapes');

var _ansiEscapes2 = _interopRequireDefault(_ansiEscapes);

var _wrapAnsi = require('wrap-ansi');

var _wrapAnsi2 = _interopRequireDefault(_wrapAnsi);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Based on https://github.com/sindresorhus/log-update/blob/master/index.js

class LogUpdate {
  constructor() {
    this.prevLineCount = 0;
  }

  render(lines) {
    const wrappedLines = (0, _wrapAnsi2.default)(lines, this.columns, {
      trim: false,
      hard: true,
      wordWrap: false
    });

    const earaseChars = _ansiEscapes2.default.eraseLines(this.prevLineCount);

    this.write(earaseChars + wrappedLines + '\n');

    this.prevLineCount = wrappedLines.split('\n').length + 1;
  }

  get columns() {
    return (process.stderr.columns || 80) - 2;
  }

  write(data) {
    process.stderr.write(data, 'utf-8');
  }

  clear() {
    this.write(_ansiEscapes2.default.eraseLines(this.prevLineCount));
    this.prevLineCount = 0;
  }

  done() {
    this.prevLineCount = 0;
  }
}
exports.default = LogUpdate;